
#ifndef KMM_PLUGIN_EXPORT_H
#define KMM_PLUGIN_EXPORT_H

#ifdef KMM_PLUGIN_STATIC_DEFINE
#  define KMM_PLUGIN_EXPORT
#  define KMM_PLUGIN_NO_EXPORT
#else
#  ifndef KMM_PLUGIN_EXPORT
#    ifdef kmm_plugin_EXPORTS
        /* We are building this library */
#      define KMM_PLUGIN_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KMM_PLUGIN_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KMM_PLUGIN_NO_EXPORT
#    define KMM_PLUGIN_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KMM_PLUGIN_DEPRECATED
#  define KMM_PLUGIN_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KMM_PLUGIN_DEPRECATED_EXPORT
#  define KMM_PLUGIN_DEPRECATED_EXPORT KMM_PLUGIN_EXPORT KMM_PLUGIN_DEPRECATED
#endif

#ifndef KMM_PLUGIN_DEPRECATED_NO_EXPORT
#  define KMM_PLUGIN_DEPRECATED_NO_EXPORT KMM_PLUGIN_NO_EXPORT KMM_PLUGIN_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KMM_PLUGIN_NO_DEPRECATED
#    define KMM_PLUGIN_NO_DEPRECATED
#  endif
#endif

#endif
